.TH LATEX 1L  22-Feb-89
.SH NAME
latex  \- text formatting and typesetting
.SH SYNOPSIS
.BR latex filename 
.PP

.SH DESCRIPTION
LaTeX
formats the interspersed generic markup commands and
text contained in the named files
and outputs a typesetter independent file (called
.I DVI
which is short for
.IR D e V ice
.IR I ndependent ).
LaTeX
capabilities and language are described in
.I LaTeX - A Document Preparation System
by Leslie Lamport, published by Addison-Wesley. Most users will also
need to consult  the 
.I Local Guide
documenting local options. LaTeX is in fact a macro
package built on top of plain TeX (q.v.), and all TeX control sequences
can be used within LaTeX, so heavy users may also need to read the 
.I TeXbook
by Donald Knuth, also published by Addison Wesley.
.PP
The parameter to LaTeX should normally be a file name;
the normal usage is to say
.RB `` latex
.IR paper ''
to start processing 
.I paper.tex.
The name ``paper'' will be the ``jobname'', and is used in forming
output file names.
If LaTeX doesn't get a file name in the first line, the jobname is ``texput''.
The default `.tex' extension can be overridden by specifying an extension
explicitly.
.PP
If there is no paper.tex in the current directory, LaTeX will look
look through a search path of directories to try to find it.
.PP
The output DVI file is written on 
.I name.dvi
where
.I name
is the jobname.
A log of error messages goes into
.I name.log, and a set of auxiliary cross-referencing information goes into
.I name.aux.
Where appropriate, LaTeX will also write files with suffixes of 
.I lot,
(list of tables)
.I lof,
(list of figures)
.I toc,
(table of contents)
and
.I ind
(index entries).
.PP
.PP
A number of output drivers are available.  At Southampton, we support
printing on PostScript devices, with the
.I dvi
command, and previewing on a Sun workstation under Suntools or
X-Windows, using respectively
.I textool
or
.I texx
(see manual pages).
.PP
There are some environment variables that can be used to set up directory
paths to search when LaTeX opens a file for input.
For example, the
.I csh
command
.br

.in +2
setenv TEXINPUTS .:/u/staff/me/mylib:/usr/local/lib/tex/inputs
.in -2

or the
.I sh
command sequence
.br

.in +2
TEXINPUTS=.:/usr/local/staff/me/mylib:/usr/local/lib/tex/inputs
.br
export TEXINPUTS
.in -2

.br
would cause all invocations of LaTeX to look for
\\input files first in the current directory, then in a hypothetical
user's ``mylib'', and finally in the system library.
Normally, the user will place the command sequence which sets up the
TEXINPUTS environment variable in the
.I .cshrc
or
.I .profile
file.
The Environment section below lists the relevant environment variables,
and their defaults.
.PP
The
.I e
response to LaTeX's error prompt causes the
.I vi
editor to start up at the current line of the current file.
There is an environment variable, TEXEDIT, that can be used to change the
editor used.  It should contain a string with "%s" indicating where the
filename goes and "%d" indicating where the decimal linenumber (if any) goes.
For example, a TEXEDIT string for 
.I gnuemacs
can be set by:
.br
.ti +2
setenv TEXEDIT "emacs -l/usr/local/emacs/lisp/tex-start -estartline %d %s"
.br
(replacing the path name for the emacs as appropriate on your system).
.PP
.PP
A convenient file in the library is null.tex, containing nothing.
When tex can't find a file it thinks you want to input, it keeps
asking you for another file name;  responding `null' gets you out
of the loop if you don't want to input anything.
.PP
.SH ENVIRONMENT
.PP
.IP TEXINPUTS
Search path for \\input and \\openin files.  It should be colon-separated,
and start with ``.''.  The entire path must be no longer than 700
characters long.
Default: .:/usr/local/lib/tex/inputs
.IP TEXFONTS
Search path for font metric files.  The entire path must be no longer than 100
characters long.  The default doesn't include the current area (".") to
avoid confusing the programs that convert the output for printing on the
various output devices.
Default: /usr/local/lib/tex/fonts
.IP TEXFORMATS
Search path for format files.  Default: .:/usr/local/lib/tex/formats
.IP TEXPOOL
Search path for TeX strings.  Default: .:/usr/local/lib/tex/tex82
.IP TEXEDIT
Command template for switching to editor.  Default: "/usr/ucb/vi +%d %s"

.SH FILES

.TP 2.5i
/usr/local/lib/tex
TeX's library area
.TP
/usr/local/lib/tex/tex82
Encoded text of TeX's messages
.TP
/usr/local/lib/tex/mftfm
TeX's font width tables for Metafont-created fonts
.TP
/usr/local/lib/tex/pstfm
TeX's font width tables for PostScript fonts
.TP
/usr/local/lib/tex/pk118/*.*pk
Bit maps for low resolution devices (screen previewers)
.TP
/usr/local/lib/tex/formats
TeX system macros and .fmt files
.br
.SH "SEE ALSO"
Donald E. Knuth,
.I The TeXbook
.br
Leslie Lamport,
.I LaTeX - A Document Preparation System
.br
.I TUGBOAT
(the publication of the TeX Users Group)
.br
.I texhax
(the TUG electronic mailing list)
.SH "TRIVIA"
TeX, pronounced properly, rhymes with ``blecchhh.''  Note that the proper
spelling in typewriter-like output is ``TeX'' and not ``TEX'' or ``tex.''
LaTeX is pronounced and written
similarly, but the `La' may be pronounced `lay' or
`lah' according to preference.
.SH "BUGS"
There is no way to read a LaTeX input file with no filename extension.
.SH "AUTHORS"
TeX was designed by Donald E. Knuth, 
who implemented it using his WEB system for Pascal programs.
It was ported to Unix at Stanford by Howard Trickey, and
at Cornell by Pavel Curtis. This version is an automatic translation
into C using a program (web2c) by Tim Morgan.
The LaTeX macros were written by Leslie Lamport, now at DEC Research.
